/**********************************************************************************
 *  TITLE: Blynk control 1 Relay using ESP-01 (ESP-01/01s relay v4.0)
 *  Click on the following links to learn more. 
 *  YouTube Video: https://youtu.be/fhEU80xJi-g
 *  Related Blog : https://iotcircuithub.com/esp32-projects/
 *  by Tech StudyCell
 *  Preferences--> Aditional boards Manager URLs : 
 *  https://raw.githubusercontent.com/espressif/arduino-esp32/gh-pages/package_esp32_dev_index.json, http://arduino.esp8266.com/stable/package_esp8266com_index.json
 *  
 *  Download Board ESP8266 : https://github.com/esp8266/Arduino
 *
 *  Download the libraries 
 *  Blynk 1.2.0 Library:  https://github.com/blynkkk/blynk-library
 **********************************************************************************/

/* Fill-in your Template ID (only if using Blynk.Cloud) */
#define BLYNK_TEMPLATE_ID ""
#define BLYNK_TEMPLATE_NAME ""
#define BLYNK_AUTH_TOKEN ""

// Your WiFi credentials.
// Set password to "" for open networks.
char ssid[] = "";
char pass[] = "";

bool fetch_blynk_state = false;

#include <ESP8266WiFi.h>        
#include <BlynkSimpleEsp8266.h>

// define the GPIO connected with Relays and switches
#define RelayPin1 0  //GPIO-0

//Change the virtual pins according the rooms
#define VPIN_BUTTON_1    V1

// Relay State
bool toggleState_1 = LOW; //remember the toggle state for relay

char auth[] = BLYNK_AUTH_TOKEN;
BlynkTimer timer;

// When App button is pushed - switch the state

BLYNK_WRITE(VPIN_BUTTON_1) {
  toggleState_1 = param.asInt();
  digitalWrite(RelayPin1, !toggleState_1);
}

BLYNK_CONNECTED() {
  // Request the latest state from the server
  if (fetch_blynk_state){
    Blynk.syncVirtual(VPIN_BUTTON_1);
  }
  else{
    Blynk.virtualWrite(VPIN_BUTTON_1, toggleState_1);
  }
}

void setup()
{
  Serial.begin(9600);

  pinMode(RelayPin1, OUTPUT);

  //During Starting all Relays should TURN OFF
  digitalWrite(RelayPin1, !toggleState_1);

  WiFi.begin(ssid, pass);
  Blynk.config(auth);
  delay(1000);
  
  if (!fetch_blynk_state){
    Blynk.virtualWrite(VPIN_BUTTON_1, toggleState_1);
  }
}

void loop()
{  
  Blynk.run();
  timer.run();
  
  if (!Blynk.connected()) {
    toggleState_1 = LOW;
    digitalWrite(RelayPin1, !toggleState_1);
  }
}
